Improve this Doc View Source

Configure several aspects of error handling in AngularJS if used as a setter or return the current configuration if used as a getter. The following options are supported:

- objectMaxDepth: The maximum depth to which objects are traversed when stringified for error messages.

Omitted or undefined options will leave the corresponding configuration values unchanged.

## Usage

`angular.errorHandlingConfig([config]);`

### Arguments

Param | Type | Details
--- | --- | ---
config (optional) | Object | The configuration object. May only contain the options that need to be updated. Supported keys: `objectMaxDepth` {Number} - The max depth for stringifying objects. Setting to a non-positive or non-numeric value, removes the max depth limit. Default: 5